#!/bin/sh -e

TAR=../plexus-containers_$2.orig.tar.gz
DIR=plexus-containers-$2
TAG=$(echo plexus-containers-$2 | sed 's/~\(alpha\|beta\)/-\1-/')

svn export http://svn.codehaus.org/plexus/plexus-containers/tags/$TAG $DIR
tar -c -z -f $TAR $DIR
rm -rf $DIR